==> aroundme_0_3_3.zip: aroundme_0_3_3/www/aroundme_0_3_3/template/am_default/sn_statistics.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2004 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

?>


<table width="770" border="0" cellspacing="0" cellpadding="0">

	<tr>
		<td width="180" valign="top">
			<?php
			include $templatePath . "sn_menu.inc.tpl.php";
			?>

			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="52" alt="" /><br />

			<?php
			include $templatePath . "logo.inc.tpl.php";
			?>
		</td>

		<td width="20">&nbsp;</td>

		<td width="275" valign="top">
			<table border="0" width="100%" cellspacing="0" cellpadding="4">
				<tr>
					<td colspan="2" class="txt_title" align="right">
						<?php echo $lang['hdr_statistics'];?><br />
						<hr />
					</td>
				</tr>
				<?php
				if (isset($user_statistic[0]['statistic_type_id'])) {
				foreach($user_statistic as $key => $i):
				?>
				<tr>
					<td>
						<?php echo $lang['arr_user_statistic_type_id'][$i['statistic_type_id']];?><br />
					</td>
					<td align="right">
						<?php echo $i['total'];?><br />
					</td>
				</tr>
				<?php
				endforeach;
				} else {
				?>
				<tr>
					<td colspan="2">
						<?php echo $lang['err_no_statistics'];?><br />
					</td>
				</tr>
				<?php }?>
			</table>
		</td>

		<td width="20">&nbsp;</td>

		<td width="275" valign="top">
			<table border="0" cellspacing="0" cellpadding="4" width="100%">
				<tr>
					<td colspan="2" class="txt_title" align="right">
						<?php echo $lang['hdr_node_stats'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td>
						<table width="100%" cellpadding="4" cellspacing="0" border="0">
			    			<tr>
								<td>
									<?php echo $lang['txt_date'];?>:<br />
								</td>
								<td align="right">
									<?php echo $node_statistics['today'];?><br />
								</td>
							</tr>
							<tr>
								<td>
									<?php echo $lang['txt_total_online_users'];?>:<br />
								</td>
								<td align="right">
									<?php echo $node_statistics['total_online_users'];?><br />
								</td>
							</tr>
							<tr>
								<td>
									<?php echo $lang['txt_total_users'];?>:<br />
								</td>
								<td align="right">
									<?php echo $node_statistics['total_users'];?><br />
								</td>
							</tr>
							<tr>
								<td>
									<?php echo $lang['txt_total_groups'];?>:<br />
								</td>
								<td align="right">
									<?php echo $node_statistics['total_groups'];?><br />
								</td>
							</tr>
						</table>
					</td>
				</tr>
			</table>
		</td>
	</tr>
</table>

==> aroundme-0_4_0.zip: aroundme_0_4_0/www/aroundme_0_4_0/template/am_default/sn_statistics.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

?>


<table width="770" border="0" cellspacing="0" cellpadding="0">

	<tr>
		<td width="180" valign="top">
			<?php
			include $templatePath . "sn_menu.inc.tpl.php";
			?>

			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="52" alt="" /><br />

			<?php
			include $templatePath . "logo.inc.tpl.php";
			?>
		</td>

		<td width="20">&nbsp;</td>

		<td width="275" valign="top">
			<table border="0" width="100%" cellspacing="0" cellpadding="4">
				<tr>
					<td colspan="3" class="txt_title" align="right">
						<?php echo $lang['hdr_statistics'];?><br />
						<hr />
					</td>
				</tr>
				<?php
				if (isset($user_statistic)) {
				foreach($user_statistic as $key => $i):
				?>
				<tr>
					<td width="3" valign="top">
						<img src="<?php echo $templatePath;?>img/green_dot.png" width="3" height="9" alt="" /><br />
					</td>
					<td>
						<?php echo $lang['arr_user_statistic_type_id'][$i['statistic_type_id']];?><br />
					</td>
					<td align="right">
						<?php echo $i['total'];?><br />
					</td>
				</tr>
				<?php
				endforeach;
				} else {
				?>
				<tr>
					<td colspan="3">
						<?php echo $lang['err_no_statistics'];?><br />
					</td>
				</tr>
				<?php }?>
			</table>
		</td>

		<td width="20">&nbsp;</td>

		<td width="275" valign="top">
			<table border="0" cellspacing="0" cellpadding="4" width="100%">
				<tr>
					<td colspan="3" class="txt_title" align="right">
						<?php echo $lang['hdr_node_stats'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td width="3" valign="top">
						<img src="<?php echo $templatePath;?>img/green_dot.png" width="3" height="9" alt="" /><br />
					</td>
					<td>
						<?php echo $lang['txt_date'];?>:<br />
					</td>
					<td align="right">
						<?php echo $node_statistics['today'];?><br />
					</td>
				</tr>
				<tr>
					<td width="3" valign="top">
						<img src="<?php echo $templatePath;?>img/green_dot.png" width="3" height="9" alt="" /><br />
					</td>
					<td>
						<?php echo $lang['txt_total_online_users'];?>:<br />
					</td>
					<td align="right">
						<?php echo $node_statistics['total_online_users'];?><br />
					</td>
				</tr>
				<tr>
					<td width="3" valign="top">
						<img src="<?php echo $templatePath;?>img/green_dot.png" width="3" height="9" alt="" /><br />
					</td>
					<td>
						<?php echo $lang['txt_total_users'];?>:<br />
					</td>
					<td align="right">
						<?php echo $node_statistics['total_users'];?><br />
					</td>
				</tr>
				<tr>
					<td width="3" valign="top">
						<img src="<?php echo $templatePath;?>img/green_dot.png" width="3" height="9" alt="" /><br />
					</td>
					<td>
						<?php echo $lang['txt_total_groups'];?>:<br />
					</td>
					<td align="right">
						<?php echo $node_statistics['total_groups'];?><br />
					</td>
				</tr>
			</table>
		</td>
	</tr>
</table>
